==> cloud-print-api-java-client-1.0.0-sources.jar: com/ctaiot/bean/BrandPayLoad.java <==
package com.ctaiot.bean;

 public class BrandPayLoad {
    /**
     * 设备编号
     */
    private Long id;

    /**
     * 设备型号：(1、PC 2、AD 3、IOS 4、Mac 5、微信小程序 6、支付宝小程序)
     */
    private Integer equip;


    private Long brandId;

    private Integer languageId;

    /**
     * 客户端编号
     */
    private String clientId;

    /**
     * 打印方向
     */
    private Integer direction;
    /**
     * 水平位移
     */
    private Integer horizontalOffSet;
    /**
     * 垂直位移
     */
    private Integer verticalOffSet;
    /**
     * 打印速度
     */
    private Integer speed;
    /**
     * 打印浓度
     */
    private Integer density;
    /**
     * 选择裁剪模式
     */
    private Integer cutMode;
    /**
     * 间隔裁剪选择数量
     */
    private Integer cutInterval;
    /**
     * 纸张类型
     */
    private Integer paperType;
    /**
     * 送纸偏移
     */
    private Integer paperTranslate;
    /**
     * 纸张间距
     */
    private Integer paperMargin;
    /**
     * 指令切换
     */
    private Integer cmd;
    /**
     * 打印方式
     */
    private Integer operate;
    /**
     * esc纸张定位方式
     */
    private Integer paperEscAim;

    /**
     * esc纸张走纸行数
     */
    private Integer paperEscPush;
    /**
     *esc纸张宽度
     */
    private Integer paperEscWidth;
    /**
     * 序列号
     */
    private String sequenceCode;
    /**
     * 纸张宽度
     */
    private Integer labelWidthMM;
    /**
     * 纸张高度
     */
    private Integer labelHeightMM;
    /**
     * 模式设置
     */
    private Integer command;
    /**
     * 自动关机
     */
    private Integer autoSleep;

    private Integer paperOffsetVertical;

    private Integer paperOffsetHorizontal;

    private Integer cachePrint;

    private Integer autoShutDown;

    private Integer comnandSwitch;

    private Integer paperFeed;

    private Integer paperPosition;

    private Integer paperMode;

    public Long getId() {
       return id;
    }

    public void setId(Long id) {
       this.id = id;
    }

    public Integer getEquip() {
       return equip;
    }

    public void setEquip(Integer equip) {
       this.equip = equip;
    }

    public Long getBrandId() {
       return brandId;
    }

    public void setBrandId(Long brandId) {
       this.brandId = brandId;
    }

    public String getClientId() {
       return clientId;
    }

    public void setClientId(String clientId) {
       this.clientId = clientId;
    }

    public Integer getDirection() {
       return direction;
    }

    public void setDirection(Integer direction) {
       this.direction = direction;
    }

    public Integer getHorizontalOffSet() {
       return horizontalOffSet;
    }

    public void setHorizontalOffSet(Integer horizontalOffSet) {
       this.horizontalOffSet = horizontalOffSet;
    }

    public Integer getVerticalOffSet() {
       return verticalOffSet;
    }

    public void setVerticalOffSet(Integer verticalOffSet) {
       this.verticalOffSet = verticalOffSet;
    }

    public Integer getSpeed() {
       return speed;
    }

    public void setSpeed(Integer speed) {
       this.speed = speed;
    }

    public Integer getDensity() {
       return density;
    }

    public void setDensity(Integer density) {
       this.density = density;
    }

    public Integer getCutMode() {
       return cutMode;
    }

    public void setCutMode(Integer cutMode) {
       this.cutMode = cutMode;
    }

    public Integer getCutInterval() {
       return cutInterval;
    }

    public void setCutInterval(Integer cutInterval) {
       this.cutInterval = cutInterval;
    }

    public Integer getPaperType() {
       return paperType;
    }

    public void setPaperType(Integer paperType) {
       this.paperType = paperType;
    }

    public Integer getPaperTranslate() {
       return paperTranslate;
    }

    public void setPaperTranslate(Integer paperTranslate) {
       this.paperTranslate = paperTranslate;
    }

    public Integer getPaperMargin() {
       return paperMargin;
    }

    public void setPaperMargin(Integer paperMargin) {
       this.paperMargin = paperMargin;
    }

    public Integer getCmd() {
       return cmd;
    }

    public void setCmd(Integer cmd) {
       this.cmd = cmd;
    }

    public Integer getPaperEscAim() {
       return paperEscAim;
    }

    public void setPaperEscAim(Integer paperEscAim) {
       this.paperEscAim = paperEscAim;
    }

    public Integer getPaperEscPush() {
       return paperEscPush;
    }

    public void setPaperEscPush(Integer paperEscPush) {
       this.paperEscPush = paperEscPush;
    }

    public Integer getPaperEscWidth() {
       return paperEscWidth;
    }

    public void setPaperEscWidth(Integer paperEscWidth) {
       this.paperEscWidth = paperEscWidth;
    }

    public String getSequenceCode() {
       return sequenceCode;
    }

    public void setSequenceCode(String sequenceCode) {
       this.sequenceCode = sequenceCode;
    }

    public Integer getLabelWidthMM() {
       return labelWidthMM;
    }

    public void setLabelWidthMM(Integer labelWidthMM) {
       this.labelWidthMM = labelWidthMM;
    }

    public Integer getLabelHeightMM() {
       return labelHeightMM;
    }

    public void setLabelHeightMM(Integer labelHeightMM) {
       this.labelHeightMM = labelHeightMM;
    }

    public Integer getCommand() {
       return command;
    }

    public void setCommand(Integer command) {
       this.command = command;
    }

    public Integer getAutoSleep() {
       return autoSleep;
    }

    public void setAutoSleep(Integer autoSleep) {
       this.autoSleep = autoSleep;
    }

    public Integer getPaperOffsetVertical() {
       return paperOffsetVertical;
    }

    public void setPaperOffsetVertical(Integer paperOffsetVertical) {
       this.paperOffsetVertical = paperOffsetVertical;
    }

    public Integer getPaperOffsetHorizontal() {
       return paperOffsetHorizontal;
    }

    public void setPaperOffsetHorizontal(Integer paperOffsetHorizontal) {
       this.paperOffsetHorizontal = paperOffsetHorizontal;
    }

    public Integer getOperate() {
       return operate;
    }

    public void setOperate(Integer operate) {
       this.operate = operate;
    }

    public Integer getCachePrint() {
       return cachePrint;
    }

    public void setCachePrint(Integer cachePrint) {
       this.cachePrint = cachePrint;
    }

    public Integer getAutoShutDown() {
       return autoShutDown;
    }

    public void setAutoShutDown(Integer autoShutDown) {
       this.autoShutDown = autoShutDown;
    }

    public Integer getComnandSwitch() {
       return comnandSwitch;
    }

    public void setComnandSwitch(Integer comnandSwitch) {
       this.comnandSwitch = comnandSwitch;
    }

    public Integer getPaperFeed() {
       return paperFeed;
    }

    public void setPaperFeed(Integer paperFeed) {
       this.paperFeed = paperFeed;
    }

    public Integer getPaperPosition() {
       return paperPosition;
    }

    public void setPaperPosition(Integer paperPosition) {
       this.paperPosition = paperPosition;
    }

    public Integer getPaperMode() {
       return paperMode;
    }

    public void setPaperMode(Integer paperMode) {
       this.paperMode = paperMode;
    }

    public Integer getLanguageId() {
       return languageId;
    }

    public void setLanguageId(Integer languageId) {
       this.languageId = languageId;
    }
 }

==> cloud-print-api-java-client-1.0.3-sources.jar: com/ctaiot/bean/BrandPayLoad.java <==
package com.ctaiot.bean;

public class BrandPayLoad {
    /**
     * 设备编号
     */
    private Long id;

    /**
     * 设备型号：(1、PC 2、AD 3、IOS 4、Mac 5、微信小程序 6、支付宝小程序)
     */
    private Integer equip;


    private Long brandId;

    private String languageId;

    /**
     * 客户端编号
     */
    private String clientId;

    /**
     * 打印方向
     */
    private Integer direction;
    /**
     * 水平位移
     */
    private Integer horizontalOffSet;
    /**
     * 垂直位移
     */
    private Integer verticalOffSet;
    /**
     * 打印速度
     */
    private Integer speed;
    /**
     * 打印浓度
     */
    private Integer density;
    /**
     * 选择裁剪模式
     */
    private Integer cutMode;
    /**
     * 间隔裁剪选择数量
     */
    private Integer cutInterval;
    /**
     * 纸张类型
     */
    private Integer paperType;
    /**
     * 送纸偏移
     */
    private Integer paperTranslate;
    /**
     * 纸张间距
     */
    private Integer paperMargin;
    /**
     * 指令切换
     */
    private Integer cmd;
    /**
     * 打印方式
     */
    private Integer operate;
    /**
     * esc纸张定位方式
     */
    private Integer paperEscAim;

    /**
     * esc纸张走纸行数
     */
    private Integer paperEscPush;
    /**
     * esc纸张宽度
     */
    private Integer paperEscWidth;
    /**
     * 序列号
     */
    private String sequenceCode;
    /**
     * 纸张宽度
     */
    private Integer labelWidthMM;
    /**
     * 纸张高度
     */
    private Integer labelHeightMM;
    /**
     * 模式设置
     */
    private Integer command;
    /**
     * 自动关机
     */
    private Integer autoSleep;

    private Integer paperOffsetVertical;

    private Integer paperOffsetHorizontal;

    private Integer cachePrint;

    private Integer autoShutDown;

    private Integer comnandSwitch;

    private Integer paperFeed;

    private Integer paperPosition;

    private Integer paperMode;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getEquip() {
        return equip;
    }

    public void setEquip(Integer equip) {
        this.equip = equip;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getClientId() {
        return clientId;
    }

    public void setClientId(String clientId) {
        this.clientId = clientId;
    }

    public Integer getDirection() {
        return direction;
    }

    public void setDirection(Integer direction) {
        this.direction = direction;
    }

    public Integer getHorizontalOffSet() {
        return horizontalOffSet;
    }

    public void setHorizontalOffSet(Integer horizontalOffSet) {
        this.horizontalOffSet = horizontalOffSet;
    }

    public Integer getVerticalOffSet() {
        return verticalOffSet;
    }

    public void setVerticalOffSet(Integer verticalOffSet) {
        this.verticalOffSet = verticalOffSet;
    }

    public Integer getSpeed() {
        return speed;
    }

    public void setSpeed(Integer speed) {
        this.speed = speed;
    }

    public Integer getDensity() {
        return density;
    }

    public void setDensity(Integer density) {
        this.density = density;
    }

    public Integer getCutMode() {
        return cutMode;
    }

    public void setCutMode(Integer cutMode) {
        this.cutMode = cutMode;
    }

    public Integer getCutInterval() {
        return cutInterval;
    }

    public void setCutInterval(Integer cutInterval) {
        this.cutInterval = cutInterval;
    }

    public Integer getPaperType() {
        return paperType;
    }

    public void setPaperType(Integer paperType) {
        this.paperType = paperType;
    }

    public Integer getPaperTranslate() {
        return paperTranslate;
    }

    public void setPaperTranslate(Integer paperTranslate) {
        this.paperTranslate = paperTranslate;
    }

    public Integer getPaperMargin() {
        return paperMargin;
    }

    public void setPaperMargin(Integer paperMargin) {
        this.paperMargin = paperMargin;
    }

    public Integer getCmd() {
        return cmd;
    }

    public void setCmd(Integer cmd) {
        this.cmd = cmd;
    }

    public Integer getPaperEscAim() {
        return paperEscAim;
    }

    public void setPaperEscAim(Integer paperEscAim) {
        this.paperEscAim = paperEscAim;
    }

    public Integer getPaperEscPush() {
        return paperEscPush;
    }

    public void setPaperEscPush(Integer paperEscPush) {
        this.paperEscPush = paperEscPush;
    }

    public Integer getPaperEscWidth() {
        return paperEscWidth;
    }

    public void setPaperEscWidth(Integer paperEscWidth) {
        this.paperEscWidth = paperEscWidth;
    }

    public String getSequenceCode() {
        return sequenceCode;
    }

    public void setSequenceCode(String sequenceCode) {
        this.sequenceCode = sequenceCode;
    }

    public Integer getLabelWidthMM() {
        return labelWidthMM;
    }

    public void setLabelWidthMM(Integer labelWidthMM) {
        this.labelWidthMM = labelWidthMM;
    }

    public Integer getLabelHeightMM() {
        return labelHeightMM;
    }

    public void setLabelHeightMM(Integer labelHeightMM) {
        this.labelHeightMM = labelHeightMM;
    }

    public Integer getCommand() {
        return command;
    }

    public void setCommand(Integer command) {
        this.command = command;
    }

    public Integer getAutoSleep() {
        return autoSleep;
    }

    public void setAutoSleep(Integer autoSleep) {
        this.autoSleep = autoSleep;
    }

    public Integer getPaperOffsetVertical() {
        return paperOffsetVertical;
    }

    public void setPaperOffsetVertical(Integer paperOffsetVertical) {
        this.paperOffsetVertical = paperOffsetVertical;
    }

    public Integer getPaperOffsetHorizontal() {
        return paperOffsetHorizontal;
    }

    public void setPaperOffsetHorizontal(Integer paperOffsetHorizontal) {
        this.paperOffsetHorizontal = paperOffsetHorizontal;
    }

    public Integer getOperate() {
        return operate;
    }

    public void setOperate(Integer operate) {
        this.operate = operate;
    }

    public Integer getCachePrint() {
        return cachePrint;
    }

    public void setCachePrint(Integer cachePrint) {
        this.cachePrint = cachePrint;
    }

    public Integer getAutoShutDown() {
        return autoShutDown;
    }

    public void setAutoShutDown(Integer autoShutDown) {
        this.autoShutDown = autoShutDown;
    }

    public Integer getComnandSwitch() {
        return comnandSwitch;
    }

    public void setComnandSwitch(Integer comnandSwitch) {
        this.comnandSwitch = comnandSwitch;
    }

    public Integer getPaperFeed() {
        return paperFeed;
    }

    public void setPaperFeed(Integer paperFeed) {
        this.paperFeed = paperFeed;
    }

    public Integer getPaperPosition() {
        return paperPosition;
    }

    public void setPaperPosition(Integer paperPosition) {
        this.paperPosition = paperPosition;
    }

    public Integer getPaperMode() {
        return paperMode;
    }

    public void setPaperMode(Integer paperMode) {
        this.paperMode = paperMode;
    }

    public String getLanguageId() {
        return languageId;
    }

    public void setLanguageId(String languageId) {
        this.languageId = languageId;
    }
}
